==> hlw-core-0.0.2-20250801.094507-134-sources.jar: cn/gtmap/hlw/core/dto/third/cqzdyxx/ygxx/BdcYgxxListThridResultDTO.java <==
package cn.gtmap.hlw.core.dto.third.cqzdyxx.ygxx;

import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:wangxuebiao@gtmap.cn">wangxuebiao</a>
 * @version 2023/10/7 16:23
 * @description BdcYgxxThridResultDTO
 */
@Data
public class BdcYgxxListThridResultDTO {

    /**
     * 申请id
     */
    private String sqid;
    /**
     * 不动产权证号
     */
    private String bdcqzh;

    /**
     * 预告登记种类
     */
    private String ygdjzl;

    /**
     * 预告登记种类名称
     */
    private String ygdjzlmc;

    /**
     * 土地权利人
     */
    private String tdqlr;

    /**
     * 规划用途
     */
    private String ghyt;

    /**
     * 权利性质
     */
    private String qlxz;

    /**
     * 不动产类型
     */
    private String bdclx;

    /**
     * 土地使用起始时间
     */
    private String tdsyqssj;
    /**
     * 土地使用结束时间
     */
    private String tdsyjssj;

    /**
     * 规划用途名称
     */
    private String ghytmc;

    /**
     * 房屋性质
     */
    private String fwxz;

    /**
     * 房屋性质名称
     */
    private String fwxzmc;

    /**
     * 建筑面积
     */
    private Double jzmj;

    /**
     * 建筑面积取得价格/被担保主债权数额
     */
    private Double qdjg;

    /**
     * 权利类型
     */
    private String qllx;

    /**
     * 权利类型名称
     */
    private String qllxmc;

    /**
     * 项目ID
     */
    private String xmid;

    /**
     * 登记时间
     */
    private String djsj;

    /**
     * 登簿人
     */
    private String dbr;

    /**
     * 附记
     */
    private String fj;

    /**
     * 债务履行期限开始日期
     */
    private String zwlxksqx;

    /**
     * 债务履行期限结束日期
     */
    private String zwlxjsqx;

    /**
     * 抵押方式
     */
    private String dyfs;

    /**
     * 抵押方式名称
     */
    private String dyfsmc;

    /**
     * 宗地用途
     */
    private String zdyt;

    /**
     * 抵押方式名称
     */
    private String zdytmc;

    /**
     * 宗地面积
     */
    private String zdmj;

    /**
     * 宗地权利性质
     */
    private String zdqlxz;

    /**
     * 宗地权利性质名称
     */
    private String zdqlxzmc;

    /**
     * 房屋结构
     */
    private String fwjg;

    /**
     * 房屋结构名称
     */
    private String fwjgmc;

    /**
     * 所在层
     */
    private String szc;

    /**
     * 总层数
     */
    private String zcs;

    /**
     * 房屋类型
     */
    private String fwlx;

    /**
     * 房屋类型名称
     */
    private String fwlxmc;

    /**
     * 分摊建筑面积
     */
    private Double ftjzmj;

    /**
     * 分摊土地面积
     */
    private Double fttdmj;

    /**
     * 贷款方式
     */
    private String dkfs;

    /**
     * 贷款方式名称
     */
    private String dkfsmc;

    /**
     * 担保范围
     */
    private String dbfw;

    /**
     * 是否禁止抵押期间抵押物转让代码
     */
    private String sfjzdyqjdywzrdm;

    /**
     * 是否禁止抵押期间抵押物转让名称
     */
    private String sfjzdyqjdywzrmc;

    /**
     * 抵押顺位
     */
    private String dysw;

    /**
     * 最高债权额
     */
    private Double zgzqe;

    /**
     * 证书打印次数
     */
    private String zsdycs;

    /**
     * 合同编号
     */
    private String htbh;

    /**
     * 债务人
     */
    private String zwr;

    /**
     * 抵押物价值
     */
    private Double dywjz;

    /**
     * 权利性质
     */
    private String tdsyqlx;
    /**
     * 登记受理编号
     */
    private String djslbh;

    /**
     * 房屋实际层（与房屋所在层区分）
     */
    private String fwsjc;

    /**
     * 套内面积
     */
    private String sctnmj;

    /**
     * 权利人信息
     */
    private List<BdcYgxxQlrListThridResultDTO> qlrList;


}

==> hlw-core-0.0.2-20251023.055425-161-sources.jar: cn/gtmap/hlw/core/dto/third/cqzdyxx/ygxx/BdcYgxxListThridResultDTO.java <==
package cn.gtmap.hlw.core.dto.third.cqzdyxx.ygxx;

import cn.gtmap.hlw.core.annotation.ZdDzConfig;
import cn.gtmap.hlw.core.constant.dict.ZdDzConstant;
import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:wangxuebiao@gtmap.cn">wangxuebiao</a>
 * @version 2023/10/7 16:23
 * @description BdcYgxxThridResultDTO
 */
@Data
public class BdcYgxxListThridResultDTO {

    /**
     * 申请id
     */
    private String sqid;
    /**
     * 不动产权证号
     */
    private String bdcqzh;

    /**
     * 预告登记种类
     */
    private String ygdjzl;

    /**
     * 预告登记种类名称
     */
    private String ygdjzlmc;

    /**
     * 土地权利人
     */
    private String tdqlr;

    /**
     * 规划用途
     */
    private String ghyt;

    /**
     * 权利性质
     */
    private String qlxz;

    /**
     * 不动产类型
     */
    private String bdclx;

    /**
     * 土地使用起始时间
     */
    private String tdsyqssj;
    /**
     * 土地使用结束时间
     */
    private String tdsyjssj;

    /**
     * 规划用途名称
     */
    private String ghytmc;

    /**
     * 房屋性质
     */
    private String fwxz;

    /**
     * 房屋性质名称
     */
    private String fwxzmc;

    /**
     * 建筑面积
     */
    private Double jzmj;

    /**
     * 建筑面积取得价格/被担保主债权数额
     */
    private Double qdjg;

    /**
     * 权利类型
     */
    private String qllx;

    /**
     * 权利类型名称
     */
    private String qllxmc;

    /**
     * 项目ID
     */
    private String xmid;

    /**
     * 登记时间
     */
    private String djsj;

    /**
     * 登簿人
     */
    private String dbr;

    /**
     * 附记
     */
    private String fj;

    /**
     * 债务履行期限开始日期
     */
    private String zwlxksqx;

    /**
     * 债务履行期限结束日期
     */
    private String zwlxjsqx;

    /**
     * 抵押方式
     */
    @ZdDzConfig(field = "dyfs", tableName = ZdDzConstant.ZD_DZ_DYFS, dmToDm = true)
    private String dyfs;

    /**
     * 抵押方式名称
     */
    private String dyfsmc;

    /**
     * 宗地用途
     */
    private String zdyt;

    /**
     * 抵押方式名称
     */
    private String zdytmc;

    /**
     * 宗地面积
     */
    private String zdmj;

    /**
     * 宗地权利性质
     */
    private String zdqlxz;

    /**
     * 宗地权利性质名称
     */
    private String zdqlxzmc;

    /**
     * 房屋结构
     */
    private String fwjg;

    /**
     * 房屋结构名称
     */
    private String fwjgmc;

    /**
     * 所在层
     */
    private String szc;

    /**
     * 总层数
     */
    private String zcs;

    /**
     * 房屋类型
     */
    private String fwlx;

    /**
     * 房屋类型名称
     */
    private String fwlxmc;

    /**
     * 分摊建筑面积
     */
    private Double ftjzmj;

    /**
     * 分摊土地面积
     */
    private Double fttdmj;

    /**
     * 贷款方式
     */
    private String dkfs;

    /**
     * 贷款方式名称
     */
    private String dkfsmc;

    /**
     * 担保范围
     */
    private String dbfw;

    /**
     * 是否禁止抵押期间抵押物转让代码
     */
    private String sfjzdyqjdywzrdm;

    /**
     * 是否禁止抵押期间抵押物转让名称
     */
    private String sfjzdyqjdywzrmc;

    /**
     * 抵押顺位
     */
    private String dysw;

    /**
     * 最高债权额
     */
    private Double zgzqe;

    /**
     * 证书打印次数
     */
    private String zsdycs;

    /**
     * 合同编号
     */
    private String htbh;

    /**
     * 债务人
     */
    private String zwr;

    /**
     * 抵押物价值
     */
    private Double dywjz;

    /**
     * 权利性质
     */
    private String tdsyqlx;
    /**
     * 登记受理编号
     */
    private String djslbh;

    /**
     * 房屋实际层（与房屋所在层区分）
     */
    private String fwsjc;

    /**
     * 套内面积
     */
    private String sctnmj;

    /**
     * 权利人信息
     */
    @ZdDzConfig(field = "qlrList", tableName = "", isList = true)
    private List<BdcYgxxQlrListThridResultDTO> qlrList;


}
